@@ -1,7 +1,8 @@
 /* gdbmerrno.c - convert gdbm errors into english. */
 
 /* This file is part of GDBM, the GNU data base manager.
-   Copyright (C) 1993, 2007, 2011, 2013, 2016 Free Software Foundation, Inc.
+   Copyright (C) 1993, 2007, 2011, 2013, 2016-2018 Free Software
+   Foundation, Inc.
 
    GDBM is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -22,7 +23,13 @@
 #include "gdbmdefs.h"
 
 /* The dbm error number is placed in the variable GDBM_ERRNO. */
-gdbm_error gdbm_errno = GDBM_NO_ERROR;
+static GDBM_THREAD_LOCAL gdbm_error gdbm_errno_storage = GDBM_NO_ERROR;
+
+int *
+gdbm_errno_location (void)
+{
+  return &gdbm_errno_storage;
+}
 
 /* Store error code EC in the database structure DBF and in the
    global variable gdbm_error. 
